@@ -4,6 +4,7 @@ import os
 import tempfile
 import sys
 import subprocess
+import io
 
 try:
 	from .tiParser import TIBasicParser
@@ -27,7 +28,17 @@ def isUTF8(file):
 		return True
 
 
-def transpile(infile, outfile="stdout", decompileFile=True, forceDecompile=False, multiplication=True, floating_point=True, run=False):
+def transpile(infile, outfile="stdout", decompileFile=True, forceDecompile=False, multiplication=True, floating_point=True, turbo_draw=False, run=False):
+
+	# detect stdin
+	if not os.path.exists(infile.name):
+		# Don't auto close since we are shadowing infile
+		temp_stdin = tempfile.NamedTemporaryFile()
+		temp_stdin.write(infile.buffer.read())
+		temp_stdin.seek(0)
+		infile = temp_stdin.name
+	else:
+		infile = infile.name
 
 	decode = not isUTF8(infile) and decompileFile is True
 
@@ -36,7 +47,7 @@ def transpile(infile, outfile="stdout", decompileFile=True, forceDecompile=False
 		with tempfile.NamedTemporaryFile() as f:
 			btb.decompile_file(infile, f.name)
 			with open(f.name, 'r') as fp:
-				pythonCode = TIBasicParser([line.strip() for line in fp.readlines()], multiplication, floating_point).toPython()
+				pythonCode = TIBasicParser([line.strip() for line in fp.readlines()], multiplication, floating_point, turbo_draw).toPython()
 
 	else:
 		# Dont decompile
@@ -45,7 +56,11 @@ def transpile(infile, outfile="stdout", decompileFile=True, forceDecompile=False
 		with open(infile, 'r') as f:
 			file_lines = [line.strip() for line in f.readlines()]
 
-		pythonCode = TIBasicParser(file_lines, multiplication, floating_point).toPython()
+		pythonCode = TIBasicParser(file_lines, multiplication, floating_point, turbo_draw).toPython()
+
+	# Close temp_stdin if used
+	if 'temp_stdin' in vars() or 'temp_stdin' in globals():
+		temp_stdin.close()
 
 	# Write to outfile
 	if outfile == "stdout":
@@ -59,7 +74,7 @@ def transpile(infile, outfile="stdout", decompileFile=True, forceDecompile=False
 				proc = subprocess.Popen([sys.executable, f.name])
 				try:
 					proc.wait()
-				except Exception:
+				except (Exception, KeyboardInterrupt):
 					proc.terminate()
 	else:
 		with open(outfile, 'w') as f:
@@ -71,11 +86,13 @@ def transpile(infile, outfile="stdout", decompileFile=True, forceDecompile=False
 
 def main():
 	parser = argparse.ArgumentParser(description='TI-BASIC to Python 3 Transpiler')
-	parser.add_argument(
+	infile_argument = parser.add_argument(
 		'infile',
 		metavar='infile',
-		nargs=1,
-		help="Input file."
+		nargs='?',
+		type=argparse.FileType('r'),
+		default=(None if sys.stdin.isatty() else sys.stdin),
+		help="Input file (filename or stdin)."
 	)
 	parser.add_argument(
 		'-o',
@@ -114,6 +131,12 @@ def main():
 		dest='floating_point'
 	)
 
+	parser.add_argument(
+		'--turbo-draw',
+		action='store_true',
+		help='Remove the 0.1 second delay between drawing actions'
+	)
+
 	parser.add_argument(
 		'-r',
 		'--run',
@@ -130,7 +153,16 @@ def main():
 	)
 
 	args = parser.parse_args()
-	transpile(args.infile[0], args.outfile, args.n, args.d, args.multiplication, args.floating_point, args.run)
+
+	if hasattr(args.infile, '__getitem__'):
+		infile = args.infile[0]
+	else:
+		infile = args.infile
+
+	if infile is None:
+		raise argparse.ArgumentError(infile_argument, 'the infile argument is required')
+
+	transpile(infile, args.outfile, args.n, args.d, args.multiplication, args.floating_point, args.turbo_draw, args.run)
 
 
 if __name__ == "__main__":
