@@ -13,7 +13,7 @@ logging.basicConfig(level=logging.WARNING)
 
 
 class TIBasicParser:
-	def __init__(self, basic, multiplication, floating_point):
+	def __init__(self, basic, multiplication, floating_point, turbo_draw):
 		if isinstance(basic, list):
 			self.basic = basic
 		elif isinstance(basic, str):
@@ -23,6 +23,7 @@ class TIBasicParser:
 
 		self.multiplication = multiplication
 		self.floating_point = floating_point
+		self.turbo_draw = turbo_draw
 
 		# Utility Functions
 		self.UTILS = {"wait": {"code": [""], "imports": ["import time"], "enabled": False}, "menu": {"code": [""], "imports": ["import dialog"], "enabled": False}, "math": {"code": [""], "imports": ["import math"], "enabled": False}, 'random': {'code': [''], 'imports': ['import random'], 'enabled': False}}
@@ -38,6 +39,9 @@ class TIBasicParser:
 		if self.floating_point:
 			self.UTILS['fix_floating_point']['enabled'] = True
 
+		if self.turbo_draw:
+			self.UTILS['draw']['code'] = [line for line in self.UTILS['draw']['code'] if '@_slow' not in line]
+
 		self.drawLock = False
 
 	def convertLine(self, index, line):
@@ -410,6 +414,17 @@ class TIBasicParser:
 				self.indentLevel += 1
 				self.indentIncrease = False
 
+		# Hand of end if drawing
+		if self.UTILS['draw']['enabled'] is True:
+			# hang on end if drawing
+			self.pythonCode += [
+				'\ttry:',
+				'\t\twhile True:',
+				'\t\t\tdraw.win.getMouse()',
+				'\texcept GraphicsError:',
+				'\t\tpass'
+			]
+
 		# Decorate main with with_goto if goto is used
 		if self.UTILS["goto"]["enabled"] is True:
 			self.pythonCode.insert(0, "@with_goto")
